import React from 'react';
import {FlatList, View} from 'react-native';
import FeedItem from './FeedItem';
import FeedData from '../../services/FeedData';
import FeedDataService from '../../services/FeedData';

class Feed extends React.Component {
  state = {
    posts: [],
    userPosts: {},
  };

  async componentDidMount() {
    const [posts, userPosts] = await Promise.all([
      FeedData.getPosts(),
      this.getUserPosts(),
    ]);

    this.setState({posts, userPosts});
  }

  getUserPosts = async () => {
    const userPosts = await FeedData.getUserPosts();
    const mappedPosts = userPosts.reduce(
      (acc, curr) => ({...acc, [curr.postId]: curr}),
      {},
    );
    return mappedPosts;
  };

  onInteract = async (postId, value) => {
    await FeedDataService.postInteract(postId, value);
    const userPosts = await this.getUserPosts();
    this.setState({userPosts});
  };

  render() {
    const {userPosts} = this.state;

    return (
      <View>
        <FlatList
          data={this.state.posts}
          renderItem={({item}) => (
            <FeedItem
              {...item}
              onInteract={value => this.onInteract(item.id, value)}
              selected={item.id in userPosts && userPosts[item.id].value}
            />
          )}
          keyExtractor={item => item.titulo}
        />
      </View>
    );
  }
}

export default Feed;
