import React from 'react';
import {Text, View, StyleSheet, TouchableOpacity} from 'react-native';
import Card from '../../components/Card';
import moment from 'moment';
import Constants from '../../lib/constants';
import AntIcon from 'react-native-vector-icons/AntDesign';

const FeedItem = props => {
  const [selected, setSelected] = React.useState(props.selected);

  const onLikePress = async () => {
    const newState = !selected;
    setSelected(newState);
    props.onInteract(newState);
  };

  const iconProps = selected
    ? {name: 'like1', color: Constants.colors.primary}
    : {name: 'like2', color: Constants.colors.grayDark};

  return (
    <Card>
      <View style={styles.cardContainer}>
        <View>
          <Text style={styles.title}>{props.title}</Text>
          <Text>{props.description}</Text>
          <Text>{moment(props.eventDate.toDate()).format('DD/MM/YYYY')}</Text>
        </View>
        <TouchableOpacity onPress={onLikePress} style={styles.iconContainer}>
          <AntIcon {...iconProps} size={30} />
        </TouchableOpacity>
      </View>
    </Card>
  );
};

const styles = StyleSheet.create({
  title: {
    color: Constants.colors.primary,
    fontWeight: 'bold',
    fontSize: 20,
  },
  cardContainer: {
    flex: 1,
    flexDirection: 'row',
    justifyContent: 'space-between',
  },
  iconContainer: {
    justifyContent: 'center',
  },
});

export default FeedItem;
