import React from 'react';
import {
  View,
  Text,
  StyleSheet,
  Button,
  FlatList,
  Dimensions,
} from 'react-native';
import Constants from '../../lib/constants';
import User from '../../services/User';
import TrainingData from '../../services/TrainingData';

import {TabView, TabBar} from 'react-native-tab-view';
import Week from './Week';

const weeks = new Array(4).fill(null).map((_, i) => ({
  key: `${i + 1}`,
  title: `Semana ${i + 1}`,
}));

class Trainings extends React.Component {
  state = {
    trainings: {},
    index: 0,
    routes: weeks,
  };

  async componentDidMount() {
    const trainings = await TrainingData.getTrainings();
    if (trainings) {
      this.setState({
        trainings: trainings.reduce((acc, curr) => {
          const key = curr.week.toString();
          return {
            ...acc,
            [key]: key in acc ? [...acc[key], curr] : [curr],
          };
        }, {}),
      });
    }
  }

  static navigationOptions = {
    title: 'Treinos',
    headerStyle: {
      backgroundColor: Constants.colors.primary,
      borderBottomWidth: 0, // for ios
      elevation: 0, // for android
    },
    headerTintColor: 'white',
    tabBarLabel: 'gesiel',
  };

  logout = () => {
    User.logout().then(() => {
      this.props.navigation.navigate('Login');
    });
  };

  render() {
    return (
      <TabView
        navigationState={this.state}
        renderScene={({route, jumpTo}) =>
          this.weeksScenes[route.key]({route, jumpTo})
        }
        renderTabBar={props => (
          <TabBar
            {...props}
            style={{backgroundColor: Constants.colors.primary}}
          />
        )}
        onIndexChange={index => this.setState({index})}
        initialLayout={{width: Dimensions.get('window').width}}
      />
    );
  }

  get weeksScenes() {
    const {trainings} = this.state;

    const weeksScenes = weeks.reduce(
      (acc, {key}) => ({
        ...acc,
        [key]: props => (
          <Week
            {...props}
            index={key}
            key={key}
            trainings={key in trainings ? trainings[key] : []}
          />
        ),
      }),
      {},
    );

    return weeksScenes;
  }
}

export default Trainings;
