import React from 'react';
import {createAppContainer, createSwitchNavigator} from 'react-navigation';
import {createStackNavigator} from 'react-navigation-stack';
import {createBottomTabNavigator} from 'react-navigation-tabs';
import FontAwesome5 from 'react-native-vector-icons/FontAwesome5';

import LoginScreen from './Login/Login';
import TrainingScreen from './Trainings/Trainings';
import AuthLoading from './AuthLoading/AuthLoading';
import Constants from '../lib/constants';
import FeedScreen from './Feed/Feed';

import {View, Text} from 'react-native';


const TrainingsStack = createStackNavigator(
  {
    Trainings: {
      screen: TrainingScreen,
    },
  },
  {
    initialRouteName: 'Trainings',
  },
);

const TabNavigator = createBottomTabNavigator(
  {
    Trainings: {
      screen: TrainingsStack, navigationOptions: ({ navigation }) => ({
      title: 'Treinos',
      tabBarLabel: 'Treinos',
    })},
    Feed: {
      screen: FeedScreen, navigationOptions: ({ navigation }) => ({
      title: 'Mural',
      tabBarLabel: 'Mural',
    })},
    History: {
      screen: TrainingsStack, navigationOptions: ({ navigation }) => ({
      title: 'Histórico',
      tabBarLabel: 'Histórico',
    })},
    Profile: {
      screen: TrainingsStack, navigationOptions: ({ navigation }) => ({
      title: 'Perfil',
      tabBarLabel: 'Perfil',
    })},
  },
  {
    initialRouteName: 'Trainings',
    defaultNavigationOptions: ({navigation}) => ({
      tabBarIcon: ({focused, horizontal, tintColor}) => {
        const {routeName} = navigation.state;
        return <FontAwesome5 name={Constants.icons[routeName] || 'question'} size={25} color={tintColor} />;
      },
    }),
  },
);

const AppNavigator = createSwitchNavigator(
  {
    AuthLoading: AuthLoading,
    Login: LoginScreen,
    Trainings: TabNavigator,
  },
  {
    initialRouteName: 'AuthLoading',
    mode: 'modal',
    headerMode: 'none',
  },
);

export default createAppContainer(AppNavigator);
