import {firestore} from '../lib/firebase';
import User from './User';

class TrainingData {
  constructor() {
    this.firestore = firestore;
  }

  async getCurrentMonth() {
    const qs = await this.firestore
      .collection(`/trainings/${User.uid}/months`)
      .where('fulfilled', '==', false)
      .orderBy('index')
      .limit(1)
      .get();
    if (qs.empty) {
      throw 'Month not found';
    }
    return qs.docs[0].id;
  }

  async getTrainings() {
    const monthId = await this.getCurrentMonth();

    const qs = await this.firestore
      .collection(`/trainings/${User.uid}/months/${monthId}/trainingItems`)
      .orderBy('week')
      .orderBy('order')
      .get();

    const trainings = [];
    qs.forEach(doc => {
      if (doc.exists) {
        let data = doc.data();
        data.id = doc.id;
        trainings.push(data);
      }
    });

    const lastIndex = findLastIndex(
      trainings,
      training =>
        training.meters !== undefined && training.seconds !== undefined,
    );

    trainings.slice(0, lastIndex + 2).forEach(training => {
      training.disabled = false;
    });
    trainings.slice(lastIndex + 2, trainings.length).forEach(training => {
      training.disabled = true;
    });

    return trainings;
  }
}

function findLastIndex(array, where) {
  var index = array
    .slice()
    .reverse()
    .findIndex(where);
  var count = array.length - 1;
  var finalIndex = index >= 0 ? count - index : index;
  console.log(finalIndex);
  return finalIndex;
}

export default new TrainingData();
